pub struct Add<B>(/* private fields */)
where
B: Bundle;Expand description
EventPattern for an AddEvent on a given bundle of components.
Note
All components specified in the Bundle are treated as an OR filter
not an AND filter. For example, Add<(A, B)> will trigger if either
component A or component B is added to an entity.